SwarmPyFAC Package
==================
The swarmpyfac package is used for calculating Field Aligned Currents based on cdf-files possibly downloaded via viresclient. It contains 3 modules, where pyfac.fac is the main one, which will be automatically imported on ``import pyfac``.

For more information see the `documentation <https://swarmpyfac.readthedocs.io/en/latest/>`_.
